==> xlnl-3.3.3.tar.gz: xlnl-3.3.3/src/Key.h <==
/***************************************************************
* L&L - Labyrinths & Legends
* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
* 
* Created by BowKenKen
*   URL: https://sourceforge.jp/projects/lnl/
* 
* License is GPL
* 
* ܥץϥե꡼եȥǤ
* ʤϡ Free Software Foundation ɽ
*  GNU ̸ͭѵΡ֥С󣲡
* ϤʹߤγƥС椫餤줫򤷡
* ΥС˽äܥץ
* ۤޤѹ뤳ȤǤޤ
* 
* ܥץͭѤȤϻפޤۤˤäƤϡ
* ԾڤŪŬˤĤƤΰۤݾڤޤ,
* ʤݾڤԤʤޤ
* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
* 
* ʤϡܥץȰ GNU ̸ͭѵ
* μ̤äƤϤǤǤʤϡ
*   Free Software Foundation, Inc.,
*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
* ؼ񤤤Ƥ
* 
* $Id: Key.h,v 1.10 2008/01/11 09:13:16 bowkenken Exp $
***************************************************************/

#ifndef KEY_H
#define KEY_H	1

#ifdef D_WS
# include <WSCstring.h>
# include <WSDkeyboard.h>
#endif // D_WS

#ifdef D_GTK
# include <gtk/gtk.h>
# include <gdk/gdk.h>
# include <gdk/gdkkeysyms.h>
# include "GtkMisc.h"
# include "GtkWSCstring.h"
#endif // D_GTK

#ifdef D_MFC
# include "MfcWSCstring.h"
#endif // D_MFC

////////////////////////////////////////////////////////////////
// Ϥδ
////////////////////////////////////////////////////////////////

class Key {
public:

private:
	// ϥХåե
	WSCstring buf;

public:
	Key()
	{
	}
	~Key()
	{
	}

	void init();

	long getChar();

	void setChar( long c, bool flagCheckClear = false );
	void setString( WSCstring s, bool flagCheckClear = false );
	void setStringKeyTab( WSCstring s );

	bool chkBuf();

	bool moveCrsrAbs( long mapX, long mapY );

#ifdef D_MFC
	void handleKeyDown(
		UINT nChar, UINT nRepCnt, UINT nFlags
	);
#endif // D_MFC
};

#endif /* KEY_H */

==> xlnl-3.3.5.tar.gz: xlnl-3.3.5/src/Key.h <==
/***************************************************************
* L&L - Labyrinths & Legends
* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
* 
* Created by BowKenKen
*   URL: https://sourceforge.jp/projects/lnl/
* 
* License is GPL
* 
* ܥץϥե꡼եȥǤ
* ʤϡ Free Software Foundation ɽ
*  GNU ̸ͭѵΡ֥С󣲡
* ϤʹߤγƥС椫餤줫򤷡
* ΥС˽äܥץ
* ۤޤѹ뤳ȤǤޤ
* 
* ܥץͭѤȤϻפޤۤˤäƤϡ
* ԾڤŪŬˤĤƤΰۤݾڤޤ,
* ʤݾڤԤʤޤ
* ܺ٤ˤĤƤ GNU ̸ͭѵɤߤ
* 
* ʤϡܥץȰ GNU ̸ͭѵ
* μ̤äƤϤǤǤʤϡ
*   Free Software Foundation, Inc.,
*   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
* ؼ񤤤Ƥ
* 
* $Id: Key.h,v 1.11 2008/09/27 06:16:16 bowkenken Exp $
***************************************************************/

#ifndef KEY_H
#define KEY_H	1

#ifdef D_WS
# include <WSCstring.h>
# include <WSDkeyboard.h>
#endif // D_WS

#ifdef D_GTK
# include <gtk/gtk.h>
# include <gdk/gdk.h>
# include <gdk/gdkkeysyms.h>
# include "GtkMisc.h"
# include "GtkWSCstring.h"
#endif // D_GTK

#ifdef D_MFC
# include "MfcWSCstring.h"
#endif // D_MFC

////////////////////////////////////////////////////////////////
// Ϥδ
////////////////////////////////////////////////////////////////

class Key {
public:

private:
	// ϥХåե
	WSCstring buf;

public:
	Key()
	{
	}
	~Key()
	{
	}

	void init();

	long getChar();

	void setChar( long c, bool flagCheckClear = false );
	void setString( WSCstring s, bool flagCheckClear = false );
	void setStringKeyTab( WSCstring s );

	bool chkBuf();

	bool moveCrsrRel( long mapX, long mapY );
	bool moveCrsrAbs( long mapX, long mapY );
	bool scrollRel( long mapX, long mapY );
	bool scrollAbs( long mapX, long mapY );

#ifdef D_MFC
	void handleKeyDown(
		UINT nChar, UINT nRepCnt, UINT nFlags
	);
#endif // D_MFC
};

#endif /* KEY_H */
